package bou.amine.apps.readerforselfossv2.utils

import android.text.format.DateUtils
import kotlinx.datetime.*

actual class DateUtils {
    actual companion object {
        // Possible formats are
        // yyyy-mm-dd hh:mm:ss format
        private val oldVersionFormat = "\\d{4}-\\d{2}-\\d{2} \\d{2}:\\d{2}:\\d{2}(.()\\d*)?".toRegex()

        // yyyy-MM-dd'T'HH:mm:ss[.SSS]XXX (RFC3339)
        private val newVersionFormat = "\\d{4}-\\d{2}-\\d{2}T\\d{2}:\\d{2}:\\d{2}\\+\\d{2}(:\\d{2})?".toRegex()

        // We may need to consider moving the formatting to platform specific code, even if the tests are doubled
        // For now, we handle this in a hacky way, because kotlin only accepts iso formats
        actual fun parseDate(dateString: String): Long {
            var isoDateString: String =
                if (dateString.matches(oldVersionFormat)) {
                    dateString.replace(" ", "T")
                } else if (dateString.matches(newVersionFormat)) {
                    dateString.split("+")[0]
                } else {
                    throw Exception("Unrecognized format for $dateString")
                }

            return LocalDateTime.parse(isoDateString).toInstant(TimeZone.currentSystemDefault()).toEpochMilliseconds()
        }

        actual fun parseRelativeDate(dateString: String): String {
            val date = parseDate(dateString)

            return " " +
                DateUtils.getRelativeTimeSpanString(
                    date,
                    Clock.System.now().toEpochMilliseconds(),
                    DateUtils.MINUTE_IN_MILLIS,
                    DateUtils.FORMAT_ABBREV_RELATIVE,
                )
        }
    }
}
